@@ -1555,7 +1555,7 @@ int define_surveys(char surveynames[MAX_STRLEN][MAX_SURVEYS])
   strcpy(surveynames[20],"FermiBlind");
   strcpy(surveynames[21],"htru_pks");
   strcpy(surveynames[22],"FermiAssoc");
-  strcpy(surveynames[23],"gbt350");
+  strcpy(surveynames[23],"gb350");
   strcpy(surveynames[24],"pkspa");
   strcpy(surveynames[25],"pksngp");
   strcpy(surveynames[26],"htru_eff");
@@ -1564,14 +1564,10 @@ int define_surveys(char surveynames[MAX_STRLEN][MAX_SURVEYS])
   strcpy(surveynames[29],"ghrss");
   strcpy(surveynames[30],"pks_superb");
   strcpy(surveynames[31],"lotaas");
-  strcpy(surveynames[32],"fast_crafts");
-  strcpy(surveynames[33],"fast_gpps");
-  strcpy(surveynames[34],"chime");
-  strcpy(surveynames[35],"meerkat_trapum");
-  strcpy(surveynames[36],"tulipp");
-  strcpy(surveynames[37],"mwa_smart");
-  strcpy(surveynames[38],"pumps");
-  survey_num=38;
+  strcpy(surveynames[32],"fast_uwb");
+  strcpy(surveynames[32],"fast_gpps");
+  
+  survey_num=33;
   return survey_num;
 }
 
